# Changelog

## 0.1.0-alpha.6 (2025-06-27)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/digitalocean/gradientai-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** manual updates ([04eb1be](https://github.com/digitalocean/gradientai-python/commit/04eb1be35de7db04e1f0d4e1da8719b54a353bb5))

## 0.1.0-alpha.5 (2025-06-27)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/digitalocean/gradientai-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** define api links and meta as shared models ([8d87001](https://github.com/digitalocean/gradientai-python/commit/8d87001b51de17dd1a36419c0e926cef119f20b8))
* **api:** update OpenAI spec and add endpoint/smodels ([e92c54b](https://github.com/digitalocean/gradientai-python/commit/e92c54b05f1025b6173945524724143fdafc7728))
* **api:** update via SDK Studio ([1ae76f7](https://github.com/digitalocean/gradientai-python/commit/1ae76f78ce9e74f8fd555e3497299127e9aa6889))
* **api:** update via SDK Studio ([98424f4](https://github.com/digitalocean/gradientai-python/commit/98424f4a2c7e00138fb5eecf94ca72e2ffcc1212))
* **api:** update via SDK Studio ([299fd1b](https://github.com/digitalocean/gradientai-python/commit/299fd1b29b42f6f2581150e52dcf65fc73270862))
* **api:** update via SDK Studio ([9a45427](https://github.com/digitalocean/gradientai-python/commit/9a45427678644c34afe9792a2561f394718e64ff))
* **api:** update via SDK Studio ([abe573f](https://github.com/digitalocean/gradientai-python/commit/abe573fcc2233c7d71f0a925eea8fa9dd4d0fb91))
* **api:** update via SDK Studio ([e5ce590](https://github.com/digitalocean/gradientai-python/commit/e5ce59057792968892317215078ac2c11e811812))
* **api:** update via SDK Studio ([1daa3f5](https://github.com/digitalocean/gradientai-python/commit/1daa3f55a49b5411d1b378fce30aea3ccbccb6d7))
* **api:** update via SDK Studio ([1c702b3](https://github.com/digitalocean/gradientai-python/commit/1c702b340e4fd723393c0f02df2a87d03ca8c9bb))
* **api:** update via SDK Studio ([891d6b3](https://github.com/digitalocean/gradientai-python/commit/891d6b32e5bdb07d23abf898cec17a60ee64f99d))
* **api:** update via SDK Studio ([dcbe442](https://github.com/digitalocean/gradientai-python/commit/dcbe442efc67554e60b3b28360a4d9f7dcbb313a))
* use inference key for chat.completions.create() ([5d38e2e](https://github.com/digitalocean/gradientai-python/commit/5d38e2eb8604a0a4065d146ba71aa4a5a0e93d85))


### Bug Fixes

* **ci:** release-doctor — report correct token name ([4d2b3dc](https://github.com/digitalocean/gradientai-python/commit/4d2b3dcefdefc3830d631c5ac27b58778a299983))


### Chores

* clean up pyproject ([78637e9](https://github.com/digitalocean/gradientai-python/commit/78637e99816d459c27b4f2fd2f6d79c8d32ecfbe))
* **internal:** codegen related update ([58d7319](https://github.com/digitalocean/gradientai-python/commit/58d7319ce68c639c2151a3e96a5d522ec06ff96f))

## 0.1.0-alpha.4 (2025-06-25)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/digitalocean/gradientai-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update via SDK Studio ([d1ea884](https://github.com/digitalocean/gradientai-python/commit/d1ea884c9be72b3f8804c5ba91bf4f77a3284a6c))
* **api:** update via SDK Studio ([584f9f1](https://github.com/digitalocean/gradientai-python/commit/584f9f1304b3612eb25f1438041d287592463438))
* **api:** update via SDK Studio ([7aee6e5](https://github.com/digitalocean/gradientai-python/commit/7aee6e55a0574fc1b6ab73a1777c92e4f3a940ea))
* **api:** update via SDK Studio ([4212f62](https://github.com/digitalocean/gradientai-python/commit/4212f62b19c44bcb12c02fe396e8c51dd89d3868))
* **api:** update via SDK Studio ([b16cceb](https://github.com/digitalocean/gradientai-python/commit/b16cceb63edb4253084036b693834bde5da10943))
* **api:** update via SDK Studio ([34382c0](https://github.com/digitalocean/gradientai-python/commit/34382c06c5d61ac97572cb4977d020e1ede9d4ff))
* **api:** update via SDK Studio ([c33920a](https://github.com/digitalocean/gradientai-python/commit/c33920aba0dc1f3b8f4f890ce706c86fd452dd6b))
* **api:** update via SDK Studio ([359c8d8](https://github.com/digitalocean/gradientai-python/commit/359c8d88cec1d60f0beb810b5a0139443d0a3348))
* **api:** update via SDK Studio ([f27643e](https://github.com/digitalocean/gradientai-python/commit/f27643e1e00f606029be919a7117801facc6e5b7))
* **api:** update via SDK Studio ([e59144c](https://github.com/digitalocean/gradientai-python/commit/e59144c2d474a4003fd28b8eded08814ffa8d2f3))
* **api:** update via SDK Studio ([97e1768](https://github.com/digitalocean/gradientai-python/commit/97e17687a348b8ef218c23a06729b6edb1ac5ea9))
* **api:** update via SDK Studio ([eac41f1](https://github.com/digitalocean/gradientai-python/commit/eac41f12912b8d32ffa23d225f4ca56fa5c72505))
* **api:** update via SDK Studio ([1fa7ebb](https://github.com/digitalocean/gradientai-python/commit/1fa7ebb0080db9087b82d29e7197e44dfbb1ebed))
* **api:** update via SDK Studio ([aa2610a](https://github.com/digitalocean/gradientai-python/commit/aa2610afe7da79429e05bff64b4796de7f525681))
* **api:** update via SDK Studio ([e5c8d76](https://github.com/digitalocean/gradientai-python/commit/e5c8d768388b16c06fcc2abee71a53dcc8b3e8c5))
* **api:** update via SDK Studio ([5f700dc](https://github.com/digitalocean/gradientai-python/commit/5f700dc7a4e757015d3bd6f2e82a311114b82d77))
* **api:** update via SDK Studio ([c042496](https://github.com/digitalocean/gradientai-python/commit/c04249614917198b1eb2324438605d99b719a1cf))
* **api:** update via SDK Studio ([5ebec81](https://github.com/digitalocean/gradientai-python/commit/5ebec81604a206eba5e75a7e8990bd7711ba8f47))
* **api:** update via SDK Studio ([cac54a8](https://github.com/digitalocean/gradientai-python/commit/cac54a81a3f22d34b2de0ebfac3c68a982178cad))
* **api:** update via SDK Studio ([6d62ab0](https://github.com/digitalocean/gradientai-python/commit/6d62ab00594d70df0458a0a401f866af15a9298e))
* **api:** update via SDK Studio ([0ccc62c](https://github.com/digitalocean/gradientai-python/commit/0ccc62cb8ef387e0aaf6784db25d5f99a587e5da))
* **api:** update via SDK Studio ([e75adfb](https://github.com/digitalocean/gradientai-python/commit/e75adfbd2d035e57ae110a1d78ea40fb116975e5))
* **api:** update via SDK Studio ([8bd264b](https://github.com/digitalocean/gradientai-python/commit/8bd264b4b4686ca078bf4eb4b5462f058406df3e))
* **api:** update via SDK Studio ([6254ccf](https://github.com/digitalocean/gradientai-python/commit/6254ccf45cbe50ca8191c7149824964f5d00d82f))
* **api:** update via SDK Studio ([8f5761b](https://github.com/digitalocean/gradientai-python/commit/8f5761b1d18fb48ad7488e6f0ad771c077eb7961))
* **api:** update via SDK Studio ([f853616](https://github.com/digitalocean/gradientai-python/commit/f8536166320d1d5bacf1d10a5edb2f71691dde8b))
* **client:** add support for aiohttp ([494afde](https://github.com/digitalocean/gradientai-python/commit/494afde754f735d1ba95011fc83d23d2410fcfdd))


### Bug Fixes

* **client:** correctly parse binary response | stream ([abba5be](https://github.com/digitalocean/gradientai-python/commit/abba5be958d03a7e5ce7d1cbf8069c0bcf52ee20))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([e649dcb](https://github.com/digitalocean/gradientai-python/commit/e649dcb0f9416e9bf568cc9f3480d7e222052391))


### Chores

* **ci:** enable for pull requests ([b6b3f9e](https://github.com/digitalocean/gradientai-python/commit/b6b3f9ea85918cfc6fc7304b2d21c340d82a0083))
* **internal:** codegen related update ([4126872](https://github.com/digitalocean/gradientai-python/commit/41268721eafd33fcca5688ca5dff7401f25bdeb2))
* **internal:** codegen related update ([10b79fb](https://github.com/digitalocean/gradientai-python/commit/10b79fb1d51bcff6ed0d18e5ccd18fd1cd75af9f))
* **internal:** update conftest.py ([12e2103](https://github.com/digitalocean/gradientai-python/commit/12e210389204ff74f504e1ec3aa5ba99f1b4971c))
* **readme:** update badges ([6e40dc3](https://github.com/digitalocean/gradientai-python/commit/6e40dc3fa4e33082be7b0bbf65d07e9ae9ac6370))
* **tests:** add tests for httpx client instantiation & proxies ([7ecf66c](https://github.com/digitalocean/gradientai-python/commit/7ecf66c58a124c153a32055967beacbd1a3bbcf3))
* **tests:** run tests in parallel ([861dd6b](https://github.com/digitalocean/gradientai-python/commit/861dd6b75956f2c12814ad32b05624d8d8537d52))
* **tests:** skip some failing tests on the latest python versions ([75b4539](https://github.com/digitalocean/gradientai-python/commit/75b45398c18e75be3389be20479f54521c2e474a))
* update SDK settings ([ed595b0](https://github.com/digitalocean/gradientai-python/commit/ed595b0a23df125ffba733d7339e771997c3f149))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([5d452d7](https://github.com/digitalocean/gradientai-python/commit/5d452d7245af6c80f47f8395f1c03493dfb53a52))

## 0.1.0-alpha.3 (2025-06-12)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/digitalocean/genai-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Chores

* update SDK settings ([502bb34](https://github.com/digitalocean/genai-python/commit/502bb34e1693603cd572c756e8ce6aeba63d1283))

## 0.1.0-alpha.2 (2025-06-12)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/digitalocean/genai-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Chores

* update SDK settings ([5b3b94b](https://github.com/digitalocean/genai-python/commit/5b3b94b57a4ba7837093617aafc2ce2d21ac87f1))

## 0.1.0-alpha.1 (2025-06-12)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/digitalocean/genai-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([1e202d0](https://github.com/digitalocean/genai-python/commit/1e202d01e3582ef5284380417d9f7e195bbc8a39))
* **api:** update via SDK Studio ([e6103ad](https://github.com/digitalocean/genai-python/commit/e6103ad8134752e632cf1dae9cb09edf10fd7739))
* **api:** update via SDK Studio ([bf61629](https://github.com/digitalocean/genai-python/commit/bf61629f25376f1cc32b910fbaea9feccfef9884))
* **api:** update via SDK Studio ([c680ef3](https://github.com/digitalocean/genai-python/commit/c680ef3bac9874ef595edde2bd8f0ce5948ac6c4))
* **api:** update via SDK Studio ([a4bb08b](https://github.com/digitalocean/genai-python/commit/a4bb08ba4829b5780511b78538e5cbbc276f1965))
* **api:** update via SDK Studio ([691923d](https://github.com/digitalocean/genai-python/commit/691923d9f60b5ebe5dc34c8227273d06448945e8))
* **client:** add follow_redirects request option ([5a6d480](https://github.com/digitalocean/genai-python/commit/5a6d480aef6d4c5084f484d1b69e6f49568a8caf))


### Chores

* **docs:** remove reference to rye shell ([29febe9](https://github.com/digitalocean/genai-python/commit/29febe9affcb0ae41ec69f8aea3ae6ef53967537))
* **docs:** remove unnecessary param examples ([35ec489](https://github.com/digitalocean/genai-python/commit/35ec48915a8bd750060634208e91bd98c905b53c))
* update SDK settings ([a095281](https://github.com/digitalocean/genai-python/commit/a095281b52c7ac5f096147e67b7b2e5bf342f95e))
* update SDK settings ([d2c39ec](https://github.com/digitalocean/genai-python/commit/d2c39eceea1aaeaf0e6c2707af10c3998d222bda))
* update SDK settings ([f032621](https://github.com/digitalocean/genai-python/commit/f03262136aa46e9325ac2fae785bf48a56f0127b))
* update SDK settings ([b2cf700](https://github.com/digitalocean/genai-python/commit/b2cf700a0419f7d6e3f23ee02747fe7766a05f98))
